@@ -9,6 +9,7 @@
 #' @inheritParams cdmDoc
 #' @inheritParams nameDoc
 #' @inheritParams requireDemographicsDoc
+#' @inheritParams softValidationDoc
 #'
 #' @return A cohort table
 #'
@@ -24,12 +25,23 @@
 #'     demographicsCohort(name = "cohort3", ageRange = c(18,40), sex = "Male")
 #'
 #' attrition(cohort)
+#'
+#' # Can also create multiple demographic cohorts, and add minimum prior history requirements.
+#'
+#' cohort <- cdm |>
+#'     demographicsCohort(name = "cohort4",
+#'     ageRange = list(c(0, 19),c(20, 64),c(65, 150)),
+#'     sex = c("Male", "Female", "Both"),
+#'     minPriorObservation = 365)
+#'
+#'attrition(cohort)
 #' }
 demographicsCohort <- function(cdm,
                                name,
                                ageRange = NULL,
                                sex = NULL,
-                               minPriorObservation = NULL) {
+                               minPriorObservation = NULL,
+                               .softValidation = TRUE) {
   # initial checks
   name <- omopgenerics::validateNameArgument(name, validation = "warning")
   cdm <- omopgenerics::validateCdmArgument(cdm)
@@ -63,8 +75,10 @@ demographicsCohort <- function(cdm,
     ageRange = ageRange,
     sex = sex,
     minPriorObservation = minPriorObservation,
-    name = name
+    name = name,
+    .softValidation = .softValidation
   )
 
   return(cdm[[name]])
+
 }
