@@ -8,6 +8,7 @@
 #' @inheritParams cohortIdModifyDoc
 #' @inheritParams nameDoc
 #' @inheritParams requireDemographicsDoc
+#' @inheritParams atFirstDoc
 #' @inheritParams softValidationDoc
 #'
 #' @return The cohort table with only records for individuals satisfying the
@@ -31,6 +32,7 @@ requireDemographics <- function(cohort,
                                 sex = c("Both"),
                                 minPriorObservation = 0,
                                 minFutureObservation = 0,
+                                atFirst = FALSE,
                                 name = tableName(cohort),
                                 .softValidation = TRUE) {
   cohort <- demographicsFilter(
@@ -46,6 +48,7 @@ requireDemographics <- function(cohort,
     reqSex = TRUE,
     reqPriorObservation = TRUE,
     reqFutureObservation = TRUE,
+    atFirst = atFirst,
     .softValidation = .softValidation
   )
 
@@ -59,7 +62,6 @@ requireDemographics <- function(cohort,
 #' satisfy the specified age criteria.
 #'
 #' @inheritParams requireDemographics
-#' @inheritParams softValidationDoc
 #'
 #' @return The cohort table with only records for individuals satisfying the
 #' age requirement
@@ -77,6 +79,7 @@ requireAge <- function(cohort,
                        ageRange,
                        cohortId = NULL,
                        indexDate = "cohort_start_date",
+                       atFirst = FALSE,
                        name = tableName(cohort),
                        .softValidation = TRUE) {
   cohort <- demographicsFilter(
@@ -92,6 +95,7 @@ requireAge <- function(cohort,
     reqSex = FALSE,
     reqPriorObservation = FALSE,
     reqFutureObservation = FALSE,
+    atFirst = atFirst,
     .softValidation = .softValidation
   )
 
@@ -105,7 +109,6 @@ requireAge <- function(cohort,
 #' satisfy the specified sex criteria.
 #'
 #' @inheritParams requireDemographics
-#' @inheritParams softValidationDoc
 #'
 #' @return The cohort table with only records for individuals satisfying the
 #' sex requirement
@@ -121,6 +124,7 @@ requireAge <- function(cohort,
 requireSex <- function(cohort,
                        sex,
                        cohortId = NULL,
+                       atFirst = FALSE,
                        name = tableName(cohort),
                        .softValidation = TRUE) {
   cohort <- demographicsFilter(
@@ -136,6 +140,7 @@ requireSex <- function(cohort,
     reqSex = TRUE,
     reqPriorObservation = FALSE,
     reqFutureObservation = FALSE,
+    atFirst = atFirst,
     .softValidation = .softValidation
   )
 
@@ -149,7 +154,6 @@ requireSex <- function(cohort,
 #' where individuals satisfy the specified prior observation criteria.
 #'
 #' @inheritParams requireDemographics
-#' @inheritParams softValidationDoc
 #'
 #' @return The cohort table with only records for individuals satisfying the
 #' prior observation requirement
@@ -167,6 +171,7 @@ requirePriorObservation <- function(cohort,
                                     minPriorObservation,
                                     cohortId = NULL,
                                     indexDate = "cohort_start_date",
+                                    atFirst = FALSE,
                                     name = tableName(cohort),
                                     .softValidation = TRUE) {
   cohort <- demographicsFilter(
@@ -182,6 +187,7 @@ requirePriorObservation <- function(cohort,
     reqSex = FALSE,
     reqPriorObservation = TRUE,
     reqFutureObservation = FALSE,
+    atFirst = atFirst,
     .softValidation = .softValidation
   )
 
@@ -195,7 +201,6 @@ requirePriorObservation <- function(cohort,
 #' where individuals satisfy the specified future observation criteria.
 #'
 #' @inheritParams requireDemographics
-#' @inheritParams softValidationDoc
 #'
 #' @return The cohort table with only records for individuals satisfying the
 #' future observation requirement
@@ -214,6 +219,7 @@ requireFutureObservation <- function(cohort,
                                      minFutureObservation,
                                      cohortId = NULL,
                                      indexDate = "cohort_start_date",
+                                     atFirst = FALSE,
                                      name = tableName(cohort),
                                      .softValidation = TRUE) {
   cohort <- demographicsFilter(
@@ -229,6 +235,7 @@ requireFutureObservation <- function(cohort,
     reqSex = FALSE,
     reqPriorObservation = FALSE,
     reqFutureObservation = TRUE,
+    atFirst = atFirst,
     .softValidation = .softValidation
   )
 
@@ -247,6 +254,7 @@ demographicsFilter <- function(cohort,
                                reqSex,
                                reqPriorObservation,
                                reqFutureObservation,
+                               atFirst,
                                .softValidation) {
   # checks
   name <- omopgenerics::validateNameArgument(name, validation = "warning")
@@ -256,7 +264,8 @@ demographicsFilter <- function(cohort,
   cohortId <- omopgenerics::validateCohortIdArgument({{cohortId}}, cohort, validation = "warning")
   ageRange <- validateDemographicRequirements(ageRange, sex, minPriorObservation, minFutureObservation)
   ids <- omopgenerics::settings(cohort)$cohort_definition_id
-  omopgenerics::assertLogical(.softValidation)
+  omopgenerics::assertLogical(.softValidation, length = 1)
+  omopgenerics::assertLogical(atFirst, length = 1)
 
   if (length(cohortId) == 0) {
     cli::cli_inform("Returning entry cohort as `cohortId` is not valid.")
@@ -270,10 +279,9 @@ demographicsFilter <- function(cohort,
   }
 
   # output cohort attributes ----
-  reqCols <- c("age_range",
-               "sex",
-               "min_prior_observation",
-               "min_future_observation")[c(reqAge, reqSex, reqPriorObservation, reqFutureObservation)]
+  reqCols <- c("age_range",  "sex", "min_prior_observation","min_future_observation")[c(
+    reqAge, reqSex, reqPriorObservation, reqFutureObservation
+  )]
 
   # new settings
   ind <- reqCols %in% colnames(settings(cohort))
@@ -288,7 +296,8 @@ demographicsFilter <- function(cohort,
         "age_range" = paste0(ageRange[[1]][1], "_", ageRange[[1]][2]),
         "sex" = sex,
         "min_prior_observation" = minPriorObservation,
-        "min_future_observation" = minFutureObservation
+        "min_future_observation" = minFutureObservation,
+        "at_first" = atFirst
       ) |>
         dplyr::select(dplyr::all_of(c("cohort_definition_id", reqCols))),
       by = "cohort_definition_id"
@@ -299,14 +308,12 @@ demographicsFilter <- function(cohort,
   tmpNewCohort <- omopgenerics::uniqueTableName(tablePrefix)
   tmpUnchanged <- omopgenerics::uniqueTableName(tablePrefix)
   cdm <- filterCohortInternal(cdm, cohort, cohortId, tmpNewCohort, tmpUnchanged)
-  newCohort <- cdm[[tmpNewCohort]]
 
   # because the cohort table passed to the function might have extra columns
   # that would conflict with ones we'll add, we'll take the core table first
   # join later
-
-  newCols <- uniqueColumnName(newCohort, n = 4)
-  newCohort <- newCohort |>
+  newCols <- uniqueColumnName( cdm[[tmpNewCohort]], n = 4)
+  cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
     PatientProfiles::addDemographics(
       indexDate = indexDate,
       age  = reqAge,
@@ -320,79 +327,81 @@ demographicsFilter <- function(cohort,
       name = tmpNewCohort
     )
 
+  # atFirst
+  min_age <- ageRange[[1]][1]
+  max_age <- ageRange[[1]][2]
+  if (is.infinite(min_age)) min_age <- 0
+  if (is.infinite(max_age)) max_age <- 200
+  filterAge <- glue::glue(".data${newCols[1]} >= {min_age} & .data${newCols[1]} <= {max_age}") |> rlang::parse_exprs()
+  filterSex <- glue::glue(".data${newCols[2]} == '{sex}' | .env$sex == 'Both'") |> rlang::parse_exprs()
+  filterPriorObservation <- glue::glue(".data${newCols[3]} >= {minPriorObservation}") |> rlang::parse_exprs()
+  filterFutureObservation <- glue::glue(".data${newCols[4]} >= {minFutureObservation}") |> rlang::parse_exprs()
+  atFirstReason <- NULL
+  tmpNewCohortFirst <- NULL
+  if (atFirst) {
+    tmpNewCohortFirst <- paste0(tmpNewCohort, "_1")
+    cdm[[tmpNewCohortFirst]] <- cdm[[tmpNewCohort]] |>
+      dplyr::group_by(.data$cohort_definition_id, .data$subject_id) |>
+      dplyr::filter(.data$cohort_start_date == base::min(.data$cohort_start_date)) |>
+      dplyr::ungroup() |>
+      dplyr::compute(name = tmpNewCohortFirst, temporary = FALSE,
+                     logPrefix = "CohortConstructor_demographicsFilter_arrange_")
+    atFirstReason <- ". Requirement applied to the first entry"
+  }
+
   # filter + record attrition ----
   # age
   if (reqAge) {
-    min_age <- ageRange[[1]][1]
-    max_age <- ageRange[[1]][2]
-    if (is.infinite(min_age)) min_age <- 0
-    if (is.infinite(max_age)) max_age <- 200
     # filter
-    newCohort <- newCohort |>
-      dplyr::filter(.data[[newCols[1]]] >= .env$min_age & .data[[newCols[1]]] <= .env$max_age) |>
-      dplyr::compute(
-        name = tmpNewCohort, temporary = FALSE,
-        logPrefix = "CohortConstructor_demographicsFilter_reqAge_"
-      ) |>
+    cdm <- applyDemographicsFilter(cdm, atFirst, filterAge, tmpNewCohort, tmpNewCohortFirst)
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
       omopgenerics::recordCohortAttrition(
-        reason = "Age requirement: {ageRange[[1]][1]} to {ageRange[[1]][2]}",
+        reason = "Age requirement: {ageRange[[1]][1]} to {ageRange[[1]][2]}{atFirstReason}",
         cohortId = cohortId
       )
   }
   # sex
   if (reqSex) {
-    newCohort <- newCohort |>
-      dplyr::filter(.data[[newCols[2]]] == .env$sex) |>
-      dplyr::compute(
-        name = tmpNewCohort, temporary = FALSE,
-        logPrefix = "CohortConstructor_demographicsFilter_reqSex_"
-      ) |>
+    cdm <- applyDemographicsFilter(cdm, atFirst, filterSex, tmpNewCohort, tmpNewCohortFirst, sex = sex)
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
       omopgenerics::recordCohortAttrition(
-        reason = "Sex requirement: {sex}",
+        reason = "Sex requirement: {sex}{atFirstReason}",
         cohortId = cohortId
       )
   }
   # prior observation
   if (reqPriorObservation) {
-    newCohort <- newCohort |>
-      dplyr::filter(.data[[newCols[3]]] >= .env$minPriorObservation) |>
-      dplyr::compute(
-        name = tmpNewCohort, temporary = FALSE,
-        logPrefix = "CohortConstructor_demographicsFilter_reqPriorObservation_"
-      ) |>
+    cdm <- applyDemographicsFilter(cdm, atFirst, filterPriorObservation, tmpNewCohort, tmpNewCohortFirst)
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
       omopgenerics::recordCohortAttrition(
-        reason = "Prior observation requirement: {minPriorObservation} days",
+        reason = "Prior observation requirement: {minPriorObservation} days{atFirstReason}",
         cohortId = cohortId
       )
   }
   # future observation
   if (reqFutureObservation) {
-    newCohort <- newCohort |>
-      dplyr::filter(.data[[newCols[4]]] >= .env$minFutureObservation) |>
-      dplyr::compute(
-        name = tmpNewCohort, temporary = FALSE,
-        logPrefix = "CohortConstructor_demographicsFilter_reqFutureObservation_"
-      ) |>
+    cdm <- applyDemographicsFilter(cdm, atFirst, filterFutureObservation, tmpNewCohort, tmpNewCohortFirst)
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
       omopgenerics::recordCohortAttrition(
-        reason = "Future observation requirement: {minFutureObservation} days",
+        reason = "Future observation requirement: {minFutureObservation} days{atFirstReason}",
         cohortId = cohortId
       )
   }
 
-  newCohort <- newCohort |>
-    dplyr::select(!dplyr::any_of(newCols)) |>
+  cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
+    dplyr::select(!dplyr::any_of(c(newCols))) |>
     dplyr::compute(name = tmpNewCohort, temporary = FALSE,
                    logPrefix = "CohortConstructor_demographicsFilter_select_")
 
   if (isTRUE(needsIdFilter(cohort, cohortId))) {
-    newCohort <- newCohort |>
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
       # join non modified cohorts
       dplyr::union_all(cdm[[tmpUnchanged]]) |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE,
                      logPrefix = "CohortConstructor_demographicsFilter_union_")
   }
 
-  newCohort <- newCohort |>
+  cdm[[name]] <- cdm[[tmpNewCohort]] |>
     dplyr::compute(name = name, temporary = FALSE,
                    logPrefix = "CohortConstructor_demographicsFilter_name_") |>
     omopgenerics::newCohortTable(
@@ -404,12 +413,12 @@ demographicsFilter <- function(cohort,
   useIndexes <- getOption("CohortConstructor.use_indexes")
   if (!isFALSE(useIndexes)) {
     addIndex(
-      cohort = newCohort,
+      cohort = cdm[[name]],
       cols = c("subject_id", "cohort_start_date")
     )
   }
 
-  return(newCohort)
+  return(cdm[[name]])
 }
 
 reqDemographicsCohortSet <- function(set,
@@ -550,3 +559,30 @@ newAttribute <- function(newSet, att, cohortId) {
     dplyr::select(!"target_cohort_rand01") |>
     dplyr::union_all(att |> dplyr::filter(!.data$cohort_definition_id %in% .env$cohortId))
 }
+
+applyDemographicsFilter <- function(cdm, atFirst, filt, tmpNewCohort, tmpNewCohortFirst, sex = NULL) {
+  if (atFirst) {
+    cdm[[tmpNewCohortFirst]] <- cdm[[tmpNewCohortFirst]] |>
+      dplyr::filter(!!!filt) |>
+      dplyr::compute(
+        name = tmpNewCohortFirst, temporary = FALSE,
+        logPrefix = "CohortConstructor_demographicsFilter_reqAge1_"
+      )
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
+      dplyr::inner_join(
+        cdm[[tmpNewCohortFirst]] |>
+          dplyr::select(dplyr::all_of(c("cohort_definition_id", "subject_id"))),
+        by = c("cohort_definition_id", "subject_id")
+      ) |>
+      dplyr::compute(name = tmpNewCohort, temporary = FALSE,
+                     logPrefix = "CohortConstructor_demographicsFilter_reqAge2_")
+  } else {
+    cdm[[tmpNewCohort]] <- cdm[[tmpNewCohort]] |>
+      dplyr::filter(!!!filt) |>
+      dplyr::compute(
+        name = tmpNewCohort, temporary = FALSE,
+        logPrefix = "CohortConstructor_demographicsFilter_reqAge_"
+      )
+  }
+  return(cdm)
+}
