@@ -9,6 +9,7 @@
 #' @inheritParams nameDoc
 #' @param strata A strata list that point to columns in cohort table.
 #' @param removeStrata Whether to remove strata columns from final cohort table.
+#' @inheritParams softValidationDoc
 #'
 #' @return Cohort table stratified.
 #'
@@ -38,14 +39,19 @@ stratifyCohorts <- function(cohort,
                             strata,
                             cohortId = NULL,
                             removeStrata = TRUE,
-                            name = tableName(cohort)) {
+                            name = tableName(cohort),
+                            .softValidation = TRUE) {
   # checks
   name <- omopgenerics::validateNameArgument(name, validation = "warning")
   cohort <- omopgenerics::validateCohortArgument(cohort)
   cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
   cohortId <- omopgenerics::validateCohortIdArgument({{cohortId}}, cohort, validation = "warning")
-  strata <- validateStrata(strata, cohort)
+  if (is.character(strata)) {
+    strata <- list(strata) #https://github.com/darwin-eu-dev/omopgenerics/issues/699
+  }
+  strata <- omopgenerics::validateStrataArgument(strata, table = cohort)
   omopgenerics::assertLogical(removeStrata, length = 1)
+  omopgenerics::assertLogical(.softValidation)
 
   if (length(cohortId) == 0) {
     cli::cli_inform("Returning empty cohort as `cohortId` is not valid.")
@@ -162,10 +168,10 @@ stratifyCohorts <- function(cohort,
       cohortSetRef = newSettings,
       cohortAttritionRef = newAttrition,
       cohortCodelistRef = newCodelist,
-      .softValidation = TRUE
+      .softValidation = .softValidation
     )
 
-  omopgenerics::dropTable(cdm = cdm, name = nm)
+  omopgenerics::dropSourceTable(cdm = cdm, name = nm)
 
   useIndexes <- getOption("CohortConstructor.use_indexes")
   if (!isFALSE(useIndexes)) {
