@@ -7,6 +7,7 @@
 #' @inheritParams cohortDoc
 #' @inheritParams cohortIdSubsetDoc
 #' @inheritParams nameDoc
+#' @inheritParams softValidationDoc
 #'
 #' @return Cohort table with only cohorts in cohortId.
 #'
@@ -22,12 +23,14 @@
 #' }
 subsetCohorts <- function(cohort,
                           cohortId,
-                          name = tableName(cohort)) {
+                          name = tableName(cohort),
+                          .softValidation = TRUE) {
   # checks
   name <- omopgenerics::validateNameArgument(name, validation = "warning")
   cohort <- omopgenerics::validateCohortArgument(cohort)
   cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
   cohortId <- omopgenerics::validateCohortIdArgument({{cohortId}}, cohort, validation = "warning")
+  omopgenerics::assertLogical(.softValidation)
 
   if (length(cohortId) == 0) {
     cli::cli_inform("Returning empty cohort as `cohortId` is not valid.")
@@ -48,7 +51,7 @@ subsetCohorts <- function(cohort,
         dplyr::filter(.data$cohort_definition_id %in% .env$cohortId),
       cohortCodelistRef = attr(cohort, "cohort_codelist") |>
         dplyr::filter(.data$cohort_definition_id %in% .env$cohortId),
-      .softValidation = TRUE
+      .softValidation = .softValidation
     )
 
   useIndexes <- getOption("CohortConstructor.use_indexes")
