@@ -36,3 +36,27 @@ uniqueColumnName <- function(table, n = 1) {
   }
   return(newCols)
 }
+
+getObservationPeriodId <- function(x, name) {
+  cdm <- omopgenerics::cdmReference(x)
+  currentObsId <- x |>
+    dplyr::inner_join(
+      cdm$observation_period |>
+        dplyr::select(
+          "subject_id" ="person_id",
+          "observation_period_start_date",
+          "observation_period_end_date",
+          "observation_period_id"
+        ),
+      by = "subject_id"
+    ) |>
+    dplyr::filter(
+      .data[["cohort_start_date"]] <= .data[["observation_period_end_date"]] &
+        .data[["cohort_start_date"]] >= .data[["observation_period_start_date"]]
+    ) |>
+    dplyr::select(dplyr::all_of(c(
+     "cohort_definition_id", "subject_id", "cohort_start_date", "cohort_end_date", "observation_period_id"
+    ))) |>
+    dplyr::compute(name = name, temporary = FALSE,
+                   logPrefix = "CohortConstructor_utilities_observationPeriodId1_")
+}
