@@ -1,8 +1,67 @@
 test_that("mearurementCohorts works", {
   skip_on_cran()
+  cohort_1 <- dplyr::tibble(
+    cohort_definition_id = 1L,
+    subject_id = c(1L, 1L, 2L, 3L, 4L),
+    cohort_start_date = as.Date(c(
+      "2001-04-03", "2002-05-07", "1999-07-26", "2015-02-19", "1990-09-07"
+    )),
+    cohort_end_date = as.Date(c(
+      "2002-05-06", "2005-11-07", "2002-09-17", "2015-06-27", "2008-02-19"
+    ))
+  )
 
-  cdm <- mockCohortConstructor(con = NULL, seed = 1)
-  cdm$concept <- cdm$concept |>
+  cohort_2 <- dplyr::tibble(
+    cohort_definition_id = c(rep(1L, 5), rep(2L, 5)),
+    subject_id = c(1L, 1L, 2L, 3L, 4L, 1L, 1L, 2L, 3L, 4L),
+    cohort_start_date = as.Date(c(
+      # Cohort 1
+      "2001-04-03", "2002-05-07", "1999-07-26", "2015-02-19", "1990-09-07",
+      # Cohort 2
+      "2004-04-07", "2004-05-03", "2000-02-27", "2015-03-10", "1995-05-15"
+    )),
+    cohort_end_date = as.Date(c(
+      # Cohort 1
+      "2002-05-06", "2005-11-07", "2002-09-17", "2015-06-27", "2008-02-19",
+      # Cohort 2
+      "2004-05-02", "2005-05-25", "2001-05-18", "2015-06-15", "1995-11-14"
+    ))
+  )
+
+  obs <- dplyr::tibble(
+    observation_period_id = 1:5,
+    person_id = 1:5,
+    observation_period_start_date = as.Date(c(
+      "2000-06-03", "1999-04-05", "2015-01-15", "1989-12-09", "2012-03-18"
+    )),
+    observation_period_end_date = as.Date(c(
+      "2013-06-29", "2003-06-15", "2015-10-11", "2013-12-31", "2013-02-10"
+    )),
+    period_type_concept_id = NA_integer_
+  )
+
+  person <- dplyr::tibble(
+    person_id = 1:5,
+    gender_concept_id = c(8507L, 8507L, 8507L, 8532L, 8507L),
+    year_of_birth = c(1997L, 1963L, 1986L, 1978L, 1973L),
+    month_of_birth = c(8L, 1L, 3L, 11L, 3L),
+    day_of_birth = c(22L, 27L, 10L, 8L, 2L),
+    race_concept_id = NA_integer_,
+    ethnicity_concept_id = NA_integer_
+  )
+
+  cdm_local <- omock::mockCdmFromTables(
+    tables = list(
+      "cohort1" = cohort_1,
+      "cohort2" = cohort_2
+    ),
+    seed = 1
+  )
+
+  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "observation_period", table = obs)
+  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "person", table = person)
+
+  cdm_local$concept <- cdm_local$concept |>
     dplyr::union_all(
       dplyr::tibble(
         concept_id = c(4326744, 4298393, 45770407, 8876, 4124457, 999999, 123456) |> as.integer(),
@@ -21,7 +80,7 @@ test_that("mearurementCohorts works", {
         invalid_reason = NA
       )
     )
-  cdm$measurement <- dplyr::tibble(
+  cdm_local$measurement <- dplyr::tibble(
     measurement_id = 1:7L,
     person_id = as.integer(c(1, 1, 2, 3, 3, 1, 1)),
     measurement_concept_id = c(4326744, 4298393, 4298393, 45770407, 45770407, 123456, 123456) |> as.integer(),
@@ -31,7 +90,7 @@ test_that("mearurementCohorts works", {
     value_as_concept_id = c(0, 0, 0, 4124457, 999999, 0, 0) |> as.integer(),
     unit_concept_id = c(8876, 8876, 0, 0, 0, 0, 0) |> as.integer()
   )
-  cdm <- cdm |> copyCdm()
+  cdm <- cdm_local |> copyCdm()
 
   isDuckdb <- attr(omopgenerics::cdmSource(cdm), "source_type") == "duckdb"
   if(isDuckdb){
@@ -54,7 +113,7 @@ test_that("mearurementCohorts works", {
   )
 
   expect_true(
-    all(colnames(attr(cdm$cohort, "cohort_codelist")) == c("cohort_definition_id", "codelist_name", "concept_id", "type"))
+    all(colnames(attr(cdm$cohort, "cohort_codelist")) == c("cohort_definition_id", "codelist_name", "concept_id", "codelist_type"))
   )
 
   if(isDuckdb){
@@ -87,8 +146,8 @@ test_that("mearurementCohorts works", {
       "reason_id" = 1:6L,
       "reason" = c(
         "Initial qualifying events",
-        "Not missing record date",
         "Record in observation",
+        "Not missing record date",
         "Non-missing sex",
         "Non-missing year of birth",
         "Distinct measurement records"
@@ -199,14 +258,14 @@ test_that("mearurementCohorts works", {
       "reason_id" = rep(1:6L, 2),
       "reason" = c(
         "Initial qualifying events",
-        "Not missing record date",
         "Record in observation",
+        "Not missing record date",
         "Non-missing sex",
         "Non-missing year of birth",
         "Distinct measurement records",
         "Initial qualifying events",
-        "Not missing record date",
         "Record in observation",
+        "Not missing record date",
         "Non-missing sex",
         "Non-missing year of birth",
         "Distinct measurement records"
@@ -567,13 +626,16 @@ test_that("inObservation FALSE", {
       "measurement_date" = as.Date(c(
         "2000-01-01", "2001-08-01", "2000-03-01", "2000-11-01", "2000-02-01", "1999-11-01"
       )),
-      "measurement_type_concept_id" = 1
+      "measurement_type_concept_id" = 1,
+      "value_as_number" = as.integer(1),
+      "value_as_concept_id" = as.integer(1),
+      "unit_concept_id" = as.integer(1)
     )
   )
 
   cdm <- cdm |> copyCdm()
 
-  cdm$cohort <- conceptCohort(cdm, list(a = 1L), name = "cohort", inObservation = FALSE)
+  cdm$cohort <- measurementCohort(cdm, list(a = 1L), name = "cohort", inObservation = FALSE)
   expect_equal(
     dplyr::tibble(
       subject_id = c(1L, 1L, 1L, 2L),
@@ -586,3 +648,139 @@ test_that("inObservation FALSE", {
   expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
   CDMConnector::cdmDisconnect(cdm = cdm)
 })
+
+test_that("edge cases", {
+  # measurement table has zero rows
+  cdm <- omock::mockPerson(nPerson = 3)
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "observation_period", table = dplyr::tibble(
+      "observation_period_id" = c(1L, 2L, 3L),
+      "person_id" = c(1L, 1L, 2L),
+      "observation_period_start_date" = as.Date(c(
+        "2000-02-01", "2000-10-01", "2000-01-01"
+      )),
+      "observation_period_end_date" = as.Date(c(
+        "2000-05-01", "2000-12-01", "2000-12-01"
+      )),
+      "period_type_concept_id" = NA_integer_
+    ))
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "concept", table = dplyr::tibble(
+      "concept_id" = 1L,
+      "concept_name" = "concept 1",
+      "domain_id" = "measurement",
+      "vocabulary_id" = NA,
+      "concept_class_id" = NA,
+      "concept_code" = NA,
+      "valid_start_date" = NA,
+      "valid_end_date" = NA
+    )
+  )
+  # person 1 - out before, out after, in, in
+  # person 2 - out before
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "measurement",
+    table = dplyr::tibble(
+      "measurement_id" = as.integer(),
+      "person_id" = as.integer(),
+      "measurement_concept_id" = as.integer(),
+      "measurement_date" = as.Date(NA),
+      "measurement_type_concept_id" = as.integer(),
+      "value_as_number" = as.integer(),
+      "value_as_concept_id" = as.integer(),
+      "unit_concept_id" = as.integer()
+    )
+  )
+
+  cdm <- cdm |> copyCdm()
+  cdm$cohort <- measurementCohort(cdm, list(a = 1L), name = "cohort")
+  attrition <- attrition(cdm$cohort)
+  class(attrition) <- c("tbl_df", "tbl", "data.frame")
+  expect_equal(
+    attrition,
+    dplyr::tibble(
+      cohort_definition_id = 1L,
+      number_records = 0L,
+      number_subjects = 0L,
+      reason_id = 1L,
+      reason = "Initial qualifying events",
+      excluded_records = 0L,
+      excluded_subjects = 0L
+    )
+  )
+
+  # measurement table once subsetted to concepts of interest has zero rows
+  cdm <- omock::mockPerson(nPerson = 3)
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "observation_period", table = dplyr::tibble(
+      "observation_period_id" = c(1L, 2L, 3L),
+      "person_id" = c(1L, 1L, 2L),
+      "observation_period_start_date" = as.Date(c(
+        "2000-02-01", "2000-10-01", "2000-01-01"
+      )),
+      "observation_period_end_date" = as.Date(c(
+        "2000-05-01", "2000-12-01", "2000-12-01"
+      )),
+      "period_type_concept_id" = NA_integer_
+    ))
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "concept", table = dplyr::tibble(
+      "concept_id" = 1L,
+      "concept_name" = "concept 1",
+      "domain_id" = "measurement",
+      "vocabulary_id" = NA,
+      "concept_class_id" = NA,
+      "concept_code" = NA,
+      "valid_start_date" = NA,
+      "valid_end_date" = NA
+    )
+  )
+  cdm <- omopgenerics::insertTable(
+    cdm = cdm, name = "measurement",
+    table = dplyr::tibble(
+      "measurement_id" = 1:6 |> as.integer(),
+      "person_id" = c(1, 1, 1, 1, 1, 2) |> as.integer(),
+      "measurement_concept_id" = 1L,
+      "measurement_date" = as.Date(c(
+        "2000-01-01", "2001-08-01", "2000-03-01", "2000-11-01", "2000-02-01", "1999-11-01"
+      )),
+      "measurement_type_concept_id" = 1,
+      "value_as_number" = as.integer(1),
+      "value_as_concept_id" = as.integer(1),
+      "unit_concept_id" = as.integer(1)
+    )
+  )
+
+  cdm <- cdm |> copyCdm()
+  cdm$cohort <- measurementCohort(cdm, list(a = 2L), name = "cohort")
+  attrition <- attrition(cdm$cohort)
+  class(attrition) <- c("tbl_df", "tbl", "data.frame")
+  expect_equal(
+    attrition,
+    dplyr::tibble(
+      cohort_definition_id = 1L,
+      number_records = 0L,
+      number_subjects = 0L,
+      reason_id = 1L,
+      reason = "Initial qualifying events",
+      excluded_records = 0L,
+      excluded_subjects = 0L
+    )
+  )
+
+  cdm$cohort2 <- measurementCohort(cdm, list(a = 1L), name = "cohort2", valueAsConcept = 0)
+  attrition <- attrition(cdm$cohort2)
+  class(attrition) <- c("tbl_df", "tbl", "data.frame")
+  expect_equal(
+    attrition,
+    dplyr::tibble(
+      cohort_definition_id = 1L,
+      number_records = 0L,
+      number_subjects = 0L,
+      reason_id = 1L,
+      reason = "Initial qualifying events",
+      excluded_records = 0L,
+      excluded_subjects = 0L
+    )
+  )
+})
