@@ -1,9 +1,47 @@
-test_that("require flag in concept", {
+test_that("require flag in concept", {#need
   skip_on_cran()
-  cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4, seed = 1) |>
-    omock::mockObservationPeriod(seed = 1) |>
-    omock::mockCohort(name = c("cohort1"), numberCohorts = 2, seed = 1)
+
+  cohort_1 <- dplyr::tibble(
+    cohort_definition_id = c(1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L),
+    subject_id = c(1L, 1L, 2L, 3L, 1L, 1L, 1L, 1L),
+    cohort_start_date = as.Date(c(
+      "2003-05-17", "2004-03-11", "1999-05-03", "2015-02-25",
+      "2001-03-24", "2001-11-28", "2002-01-30", "2002-06-13"
+    )),
+    cohort_end_date = as.Date(c(
+      "2004-03-10", "2005-07-19", "2001-06-15", "2015-04-30",
+      "2001-11-27", "2002-01-29", "2002-06-12", "2005-01-15"
+    ))
+  )
+
+  person <- dplyr::tibble(
+    person_id = 1:4,
+    gender_concept_id = c(8532L, 8507L, 8507L, 8507L),
+    year_of_birth = c(1997L, 1963L, 1986L, 1978L),
+    month_of_birth = c(8L, 1L, 3L, 11L),
+    day_of_birth = c(22L, 27L, 10L, 8L),
+    race_concept_id = NA_integer_,
+    ethnicity_concept_id = NA_integer_
+  )
+
+  obs <- dplyr::tibble(
+    observation_period_id = 1:4,
+    person_id = 1:4,
+    observation_period_start_date = as.Date(c("2000-06-03", "1999-04-05", "2015-01-15", "1989-12-09")),
+    observation_period_end_date = as.Date(c("2013-06-29", "2003-06-15", "2015-10-11", "2013-12-31")),
+    period_type_concept_id = NA_integer_
+  )
+
+  cdm_local <- omock::mockCdmFromTables(
+    tables = list(
+      "cohort1" = cohort_1
+    ),
+    seed = 1
+  )
+
+  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "observation_period", table = obs)
+  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "person", table = person)
+
   cdm_local$concept <- dplyr::tibble(
     "concept_id" = 1,
     "concept_name" = "my concept",
@@ -80,8 +118,7 @@ test_that("require flag in concept", {
                       "Concept a between -Inf & Inf days relative to cohort_start_date between 1 and Inf, censoring at cohort_end_date",
                       "Initial qualifying events",
                       "Concept a between -Inf & Inf days relative to cohort_start_date between 1 and Inf, censoring at cohort_end_date")))
-
-  # name
+ # name
   cdm$cohort1 <-  requireConceptIntersect(cohort = cdm$cohort1,
                                           conceptSet = list(a = 1L),
                                           window = c(-Inf, Inf))
@@ -119,10 +156,46 @@ test_that("require flag in concept", {
 
 test_that("requiring absence in another cohort", {
   testthat::skip_on_cran()
-  cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4, seed = 1) |>
-    omock::mockObservationPeriod(seed = 1) |>
-    omock::mockCohort(name = c("cohort1"), numberCohorts = 2, seed = 1)
+  cohort_1 <- dplyr::tibble(
+    cohort_definition_id = c(1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L),
+    subject_id = c(1L, 1L, 2L, 3L, 1L, 1L, 1L, 1L),
+    cohort_start_date = as.Date(c(
+      "2003-05-17", "2004-03-11", "1999-05-03", "2015-02-25",
+      "2001-03-24", "2001-11-28", "2002-01-30", "2002-06-13"
+    )),
+    cohort_end_date = as.Date(c(
+      "2004-03-10", "2005-07-19", "2001-06-15", "2015-04-30",
+      "2001-11-27", "2002-01-29", "2002-06-12", "2005-01-15"
+    ))
+  )
+
+  person <- dplyr::tibble(
+    person_id = 1:4,
+    gender_concept_id = c(8532L, 8507L, 8507L, 8507L),
+    year_of_birth = c(1997L, 1963L, 1986L, 1978L),
+    month_of_birth = c(8L, 1L, 3L, 11L),
+    day_of_birth = c(22L, 27L, 10L, 8L),
+    race_concept_id = NA_integer_,
+    ethnicity_concept_id = NA_integer_
+  )
+
+  obs <- dplyr::tibble(
+    observation_period_id = 1:4,
+    person_id = 1:4,
+    observation_period_start_date = as.Date(c("2000-06-03", "1999-04-05", "2015-01-15", "1989-12-09")),
+    observation_period_end_date = as.Date(c("2013-06-29", "2003-06-15", "2015-10-11", "2013-12-31")),
+    period_type_concept_id = NA_integer_
+  )
+
+  cdm_local <- omock::mockCdmFromTables(
+    tables = list(
+      "cohort1" = cohort_1
+    ),
+    seed = 1
+  )
+
+  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "observation_period", table = obs)
+  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "person", table = person)
   cdm_local$concept <- dplyr::tibble(
     "concept_id" = 1,
     "concept_name" = "my concept",
@@ -199,7 +272,7 @@ test_that("requiring absence in another cohort", {
   PatientProfiles::mockDisconnect(cdm)
 })
 
-test_that("different intersection count requirements", {
+test_that("different intersection count requirements", {#need
   testthat::skip_on_cran()
 
   cohort1 <- dplyr::tibble(
@@ -307,7 +380,7 @@ test_that("different intersection count requirements", {
   PatientProfiles::mockDisconnect(cdm)
 })
 
-test_that("test indexes - postgres", {
+test_that("test indexes - postgres, atFirst", {
   skip_on_cran()
   skip_if(Sys.getenv("CDM5_POSTGRESQL_DBNAME") == "")
   skip_if(!testIndexes)
@@ -324,6 +397,10 @@ test_that("test indexes - postgres", {
     writePrefix = "cc_test_",
     achillesSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
   )
+
+  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::contains("og_"))
+  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::contains("my_cohort"))
+
   cdm <- omopgenerics::insertTable(cdm = cdm,
                                    name = "my_cohort",
                                    table = data.frame(cohort_definition_id = 1L,
@@ -344,6 +421,44 @@ test_that("test indexes - postgres", {
       "CREATE INDEX cc_test_my_cohort_subject_id_cohort_start_date_idx ON public.cc_test_my_cohort USING btree (subject_id, cohort_start_date)"
   )
 
+  # atFirst
+  cohort <- dplyr::tibble(
+    cohort_definition_id = c(rep(1L, 4), rep(2L, 4)),
+    subject_id = c(1L, 1L, 2L, 3L, rep(1L, 4)),
+    cohort_start_date = as.Date(c(
+      "2008-05-17", "2009-03-11", "2010-05-03", "2010-02-25",
+      "2008-03-24", "2008-11-28", "2010-01-30", "2009-06-13"
+    )),
+    cohort_end_date = as.Date(c(
+      "2009-03-10", "2009-07-19", "2010-06-15", "2010-04-30",
+      "2008-11-27", "2008-01-29", "2010-06-12", "2010-01-15"
+    ))
+  )
+  cdm <- omopgenerics::insertTable(cdm = cdm,
+                                   name = "my_cohort",
+                                   table = cohort)
+  cdm$my_cohort <- omopgenerics::newCohortTable(cdm$my_cohort, .softValidation = TRUE)
+  cdm$my_cohort_1 <- requireConceptIntersect(cohort = cdm$my_cohort,
+                                            conceptSet = list(a = 22340),
+                                            window = list(c(0, 365)),
+                                            atFirst = TRUE,
+                                            name = "my_cohort_1")
+  expect_equal(
+    collectCohort(cdm$my_cohort_1, 2),
+    dplyr::tibble(
+      subject_id = 1L,
+      cohort_start_date = as.Date(NULL),
+      cohort_end_date = as.Date(NULL)
+    )
+  )
+  expect_equal(
+    attrition(cdm$my_cohort_1)$reason,
+    c('Initial qualifying events',
+      'Concept a between 0 & 365 days relative to cohort_start_date between 1 and Inf. Requirement applied to the first entry',
+      'Initial qualifying events',
+      'Concept a between 0 & 365 days relative to cohort_start_date between 1 and Inf. Requirement applied to the first entry'
+    ))
+
   expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
   omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::starts_with("my_cohort"))
   CDMConnector::cdmDisconnect(cdm = cdm)
@@ -371,7 +486,7 @@ test_that("codelists", {
       cohort_definition_id = 1:2,
       codelist_name = "a",
       concept_id = 194152L,
-      type = "inclusion criteria"
+      codelist_type = "inclusion criteria"
     )
   )
 
@@ -386,7 +501,7 @@ test_that("codelists", {
       cohort_definition_id = c(1L, 1L, 2L, 2L),
       codelist_name = c("a", "a", "b", "a"),
       concept_id = c(194152L, 194152L, 4151660L, 194152L),
-      type = c("index event", "inclusion criteria", "index event", "inclusion criteria")
+      codelist_type = c("index event", "inclusion criteria", "index event", "inclusion criteria")
     )
   )
 
